Learn R Programming

bayesbr (version 0.0.1.0)

StressAnxiety: Dependency of Anxiety on Stress

Description

For this data, stress and anxiety were measured among nonclinical women in Townsville, Queensland, Australia.

Usage

data("StressAnxiety")

Arguments

Format

A data frame containing 166 observations on 2 variables.

stress

score, linearly transformed to the open unit interval (see below).

anxiety

score, linearly transformed to the open unit interval (see below).

Details

Both variables were evaluated on the scales from 0 to 42, Smithson and Verkuilen (2006) transformed them in a range from 0 to 1.

References

10.1037/1082-989X.11.1.54 Smithson, M., and Verkuilen, J. (2006). A Better Lemon Squeezer? Maximum-Likelihood Regression with Beta-Distributed Dependent Variables. Psychological Methods, 11(7), 54--71.

Examples

Run this code
# NOT RUN {
data("StressAnxiety", package = "bayesbr")
bbr <- bayesbr(anxiety ~ stress | stress,
              data = StressAnxiety, iter = 100)

summary(bbr)
# }

Run the code above in your browser using DataLab