For this data, stress and anxiety were measured among nonclinical women in Townsville, Queensland, Australia.
Usage
data("StressAnxiety")
Arguments
Format
A data frame containing 166 observations on 2 variables.
stress
score, linearly transformed to the open unit
interval (see below).
anxiety
score, linearly transformed to the open unit
interval (see below).
Details
Both variables were evaluated on the scales from 0 to 42, Smithson and Verkuilen (2006) transformed them in a range from 0 to 1.
References
10.1037/1082-989X.11.1.54 Smithson, M., and Verkuilen, J. (2006).
A Better Lemon Squeezer? Maximum-Likelihood Regression with
Beta-Distributed Dependent Variables.
Psychological Methods, 11(7), 54--71.